@@ -9,10 +9,12 @@
 #' get_account("109302436954721982")
 #' }
 #' @export
-get_account <- function(id,instance = NULL, token = NULL, anonymous = FALSE, parse = TRUE){
-  process_request(token = token,path = paste0("api/v1/accounts/",id), instance = instance,
-                  anonymous = anonymous,
-                  parse = parse, FUN = parse_account)
+get_account <- function(id, instance = NULL, token = NULL, anonymous = FALSE, parse = TRUE) {
+  process_request(
+    token = token, path = paste0("api/v1/accounts/", id), instance = instance,
+    anonymous = anonymous,
+    parse = parse, FUN = parse_account
+  )
 }
 
 #' Search the instance for a specific user
@@ -27,11 +29,13 @@ get_account <- function(id,instance = NULL, token = NULL, anonymous = FALSE, par
 #' search_accounts("schochastics")
 #' }
 #' @export
-search_accounts <- function(query,limit = 40, token = NULL, anonymous = FALSE, parse = TRUE){
-  params <- list(q=query,limit = limit)
-  process_request(token = token,path = "/api/v1/accounts/search", instance = NULL,
-                  params = params, anonymous = anonymous,
-                  parse = parse, FUN = v(parse_account))
+search_accounts <- function(query, limit = 40, token = NULL, anonymous = FALSE, parse = TRUE) {
+  params <- list(q = query, limit = limit)
+  process_request(
+    token = token, path = "/api/v1/accounts/search", instance = NULL,
+    params = params, anonymous = anonymous,
+    parse = parse, FUN = v(parse_account)
+  )
 }
 
 #' Get statuses from a user
@@ -50,24 +54,26 @@ search_accounts <- function(query,limit = 40, token = NULL, anonymous = FALSE, p
 #' get_account_statuses("109302436954721982")
 #' }
 #' @export
-get_account_statuses <- function(id, max_id,since_id,min_id, limit = 20L,
+get_account_statuses <- function(id, max_id, since_id, min_id, limit = 20L,
                                  exclude_reblogs = FALSE, hashtag,
                                  instance = NULL,
                                  token = NULL,
                                  anonymous = FALSE,
                                  parse = TRUE,
-                                 retryonratelimit = TRUE,verbose = TRUE){
-  params <- handle_params(list(limit = min(limit,20L),exclude_reblogs = exclude_reblogs), max_id, since_id, min_id)
+                                 retryonratelimit = TRUE, verbose = TRUE) {
+  params <- handle_params(list(limit = min(limit, 20L), exclude_reblogs = exclude_reblogs), max_id, since_id, min_id)
   if (!missing(hashtag)) {
     params$tagged <- gsub("^#+", "", hashtag)
   }
-  process_request(token = token,path = paste0("api/v1/accounts/",id,"/statuses"),
-                  instance = instance,
-                  params = params, anonymous = anonymous,
-                  parse = parse, FUN = v(parse_status),
-                  n = limit, page_size = 20L,
-                  retryonratelimit = retryonratelimit,
-                  verbose = verbose)
+  process_request(
+    token = token, path = paste0("api/v1/accounts/", id, "/statuses"),
+    instance = instance,
+    params = params, anonymous = anonymous,
+    parse = parse, FUN = v(parse_status),
+    n = limit, page_size = 20L,
+    retryonratelimit = retryonratelimit,
+    verbose = verbose
+  )
 }
 
 #' Get followers of a user
@@ -84,18 +90,20 @@ get_account_statuses <- function(id, max_id,since_id,min_id, limit = 20L,
 #' get_account_followers("109302436954721982")
 #' }
 #' @export
-get_account_followers <- function(id,max_id,since_id,
+get_account_followers <- function(id, max_id, since_id,
                                   limit = 40L,
                                   token = NULL,
                                   parse = TRUE,
                                   retryonratelimit = TRUE,
-                                  verbose = TRUE){
-  params <- handle_params(list(limit = min(limit,40L)), max_id, since_id)
-  process_request(token = token,path = paste0("api/v1/accounts/",id,"/followers"),
-                  params = params,
-                  parse = parse, FUN = v(parse_account),
-                  n = limit, retryonratelimit = retryonratelimit,
-                  verbose = verbose)
+                                  verbose = TRUE) {
+  params <- handle_params(list(limit = min(limit, 40L)), max_id, since_id)
+  process_request(
+    token = token, path = paste0("api/v1/accounts/", id, "/followers"),
+    params = params,
+    parse = parse, FUN = v(parse_account),
+    n = limit, retryonratelimit = retryonratelimit,
+    verbose = verbose
+  )
 }
 #' Get accounts a user follows
 #' @inheritParams get_account_statuses
@@ -108,15 +116,17 @@ get_account_followers <- function(id,max_id,since_id,
 #' get_account_following("109302436954721982")
 #' }
 #' @export
-get_account_following <- function(id,max_id,since_id,limit = 40L,
+get_account_following <- function(id, max_id, since_id, limit = 40L,
                                   token = NULL, parse = TRUE,
                                   retryonratelimit = TRUE,
-                                  verbose = TRUE){
-  params <- handle_params(list(limit = min(limit,40L)), max_id, since_id)
-  process_request(token = token,path = paste0("api/v1/accounts/",id,"/following"),
-                  params = params,
-                  parse = parse, FUN = v(parse_account),
-                  n = limit, retryonratelimit = retryonratelimit, verbose = verbose)
+                                  verbose = TRUE) {
+  params <- handle_params(list(limit = min(limit, 40L)), max_id, since_id)
+  process_request(
+    token = token, path = paste0("api/v1/accounts/", id, "/following"),
+    params = params,
+    parse = parse, FUN = v(parse_account),
+    n = limit, retryonratelimit = retryonratelimit, verbose = verbose
+  )
 }
 
 #' Get featured tags of a user
@@ -128,9 +138,11 @@ get_account_following <- function(id,max_id,since_id,limit = 40L,
 #' get_account_featured_tags("109302436954721982")
 #' }
 #' @export
-get_account_featured_tags <- function(id,token = NULL, parse = TRUE){
-  process_request(token = token,path = paste0("api/v1/accounts/",id,"/featured_tags"),
-                  parse = parse, FUN = v(identity))
+get_account_featured_tags <- function(id, token = NULL, parse = TRUE) {
+  process_request(
+    token = token, path = paste0("api/v1/accounts/", id, "/featured_tags"),
+    parse = parse, FUN = v(identity)
+  )
 }
 
 #' Get lists containing the user
@@ -142,9 +154,11 @@ get_account_featured_tags <- function(id,token = NULL, parse = TRUE){
 #' get_account_lists("109302436954721982")
 #' }
 #' @export
-get_account_lists <- function(id,token = NULL, parse = TRUE){
-  process_request(token = token,path = paste0("api/v1/accounts/",id,"/lists"),
-                  parse = parse, FUN = v(identity))
+get_account_lists <- function(id, token = NULL, parse = TRUE) {
+  process_request(
+    token = token, path = paste0("api/v1/accounts/", id, "/lists"),
+    parse = parse, FUN = v(identity)
+  )
 }
 
 #' Find out whether a given account is followed, blocked, muted, etc.
@@ -158,13 +172,15 @@ get_account_lists <- function(id,token = NULL, parse = TRUE){
 #' get_account_relationships(fol$id)
 #' }
 #' @export
-get_account_relationships <- function(ids,token = NULL, parse = TRUE){
-  ids_lst <- lapply(ids,identity)
-  names(ids_lst) <- rep("id[]",length(ids_lst))
+get_account_relationships <- function(ids, token = NULL, parse = TRUE) {
+  ids_lst <- lapply(ids, identity)
+  names(ids_lst) <- rep("id[]", length(ids_lst))
   params <- ids_lst
-  process_request(token = token, path = "/api/v1/accounts/relationships",
-                  params = params,
-                  parse = parse, FUN = v(identity))
+  process_request(
+    token = token, path = "/api/v1/accounts/relationships",
+    params = params,
+    parse = parse, FUN = v(identity)
+  )
 }
 
 #' Get bookmarks of user
@@ -179,15 +195,17 @@ get_account_relationships <- function(ids,token = NULL, parse = TRUE){
 #' get_account_followers("109302436954721982")
 #' }
 #' @export
-get_account_bookmarks <- function(max_id,since_id,min_id,limit = 40L,
+get_account_bookmarks <- function(max_id, since_id, min_id, limit = 40L,
                                   token = NULL, parse = TRUE,
                                   retryonratelimit = TRUE,
-                                  verbose = TRUE){
-  params <- handle_params(list(limit = min(limit,40L)), max_id, since_id, min_id)
-  process_request(token = token, path = "api/v1/bookmarks",
-                  params = params,
-                  parse = parse, FUN = v(parse_status), n = limit,
-                  retryonratelimit = retryonratelimit, verbose = verbose)
+                                  verbose = TRUE) {
+  params <- handle_params(list(limit = min(limit, 40L)), max_id, since_id, min_id)
+  process_request(
+    token = token, path = "api/v1/bookmarks",
+    params = params,
+    parse = parse, FUN = v(parse_status), n = limit,
+    retryonratelimit = retryonratelimit, verbose = verbose
+  )
 }
 
 #' Get favourites of user
@@ -203,15 +221,17 @@ get_account_bookmarks <- function(max_id,since_id,min_id,limit = 40L,
 #' get_account_favourites()
 #' }
 #' @export
-get_account_favourites <- function(max_id,min_id,limit = 40L,
+get_account_favourites <- function(max_id, min_id, limit = 40L,
                                    token = NULL, parse = TRUE,
                                    retryonratelimit = TRUE,
-                                   verbose = TRUE){
-  params <- handle_params(list(limit = min(limit,40L)), max_id = max_id, min_id = min_id)
-  process_request(token = token,path = "api/v1/favourites",
-                  params = params,
-                  parse = parse, FUN = v(parse_status), n = limit,
-                  retryonratelimit = retryonratelimit, verbose = verbose)
+                                   verbose = TRUE) {
+  params <- handle_params(list(limit = min(limit, 40L)), max_id = max_id, min_id = min_id)
+  process_request(
+    token = token, path = "api/v1/favourites",
+    params = params,
+    parse = parse, FUN = v(parse_status), n = limit,
+    retryonratelimit = retryonratelimit, verbose = verbose
+  )
 }
 
 #' Get blocks of user
@@ -226,15 +246,17 @@ get_account_favourites <- function(max_id,min_id,limit = 40L,
 #' get_account_blocks()
 #' }
 #' @export
-get_account_blocks <- function(max_id,since_id,limit = 40L,
+get_account_blocks <- function(max_id, since_id, limit = 40L,
                                token = NULL, parse = TRUE,
                                retryonratelimit = TRUE,
-                               verbose = TRUE){
-  params <- handle_params(list(limit = min(limit,40L)), max_id, since_id)
-  process_request(token = token,path = "api/v1/blocks",
-                  params = params,
-                  parse = parse, FUN = v(parse_account), n = limit,
-                  retryonratelimit = retryonratelimit, verbose = verbose)
+                               verbose = TRUE) {
+  params <- handle_params(list(limit = min(limit, 40L)), max_id, since_id)
+  process_request(
+    token = token, path = "api/v1/blocks",
+    params = params,
+    parse = parse, FUN = v(parse_account), n = limit,
+    retryonratelimit = retryonratelimit, verbose = verbose
+  )
 }
 
 #' Get mutes of user
@@ -249,14 +271,16 @@ get_account_blocks <- function(max_id,since_id,limit = 40L,
 #' get_account_mutes()
 #' }
 #' @export
-get_account_mutes <- function(max_id,since_id,limit = 40L,
+get_account_mutes <- function(max_id, since_id, limit = 40L,
                               token = NULL, parse = TRUE,
                               retryonratelimit = TRUE,
-                              verbose = TRUE){
-  params <- handle_params(list(limit = min(limit,40L)), max_id, since_id)
-  process_request(token = token,path = "api/v1/mutes",
-                  params = params,
-                  parse = parse, FUN = v(parse_account),
-                  n = limit, retryonratelimit = retryonratelimit,
-                  verbose = verbose)
+                              verbose = TRUE) {
+  params <- handle_params(list(limit = min(limit, 40L)), max_id, since_id)
+  process_request(
+    token = token, path = "api/v1/mutes",
+    params = params,
+    parse = parse, FUN = v(parse_account),
+    n = limit, retryonratelimit = retryonratelimit,
+    verbose = verbose
+  )
 }
