@@ -9,8 +9,10 @@ test_that("post_toot, defensive", {
   ## no alt text, but with media
   expect_error(post_toot("testing in progress, please ignore", media = "../testdata/logo.png", token = fake_token))
   ## super long alttext
-  expect_error(post_toot("testing in progress, please ignore", media = "../testdata/logo.png",
-                         alt_text = paste(rep("a", 3000), collapse = ""), token = fake_token))
+  expect_error(post_toot("testing in progress, please ignore",
+    media = "../testdata/logo.png",
+    alt_text = paste(rep("a", 3000), collapse = ""), token = fake_token
+  ))
 })
 
 test_that("post_toot, real", {
@@ -18,24 +20,34 @@ test_that("post_toot, real", {
     expect_error(x <- post_toot(status = "testing in progress, please ignore", token = fake_token, verbose = FALSE), NA)
   })
   vcr::use_cassette("post_toot_media", {
-    expect_error(x <- post_toot(status = "testing in progress, please ignore", media = "../testdata/logo.png", alt_text = "rtoot logo",
-                                token = fake_token, verbose = FALSE), NA)
+    expect_error(x <- post_toot(
+      status = "testing in progress, please ignore", media = "../testdata/logo.png", alt_text = "rtoot logo",
+      token = fake_token, verbose = FALSE
+    ), NA)
   })
   vcr::use_cassette("post_toot_spoiler_text", {
-    expect_error(x <- post_toot(status = "testing in progress, please ignore", media = "../testdata/logo.png", alt_text = "rtoot logo",
-                                spoiler_text = "rtoot is the best", token = fake_token, verbose = FALSE), NA)
+    expect_error(x <- post_toot(
+      status = "testing in progress, please ignore", media = "../testdata/logo.png", alt_text = "rtoot logo",
+      spoiler_text = "rtoot is the best", token = fake_token, verbose = FALSE
+    ), NA)
   })
   vcr::use_cassette("post_toot_sensitive", {
-    expect_error(x <- post_toot(status = "testing in progress, please ignore", media = "../testdata/logo.png", alt_text = "rtoot logo",
-                                spoiler_text = "rtoot is the best", sensitive = TRUE, token = fake_token, verbose = FALSE), NA)
+    expect_error(x <- post_toot(
+      status = "testing in progress, please ignore", media = "../testdata/logo.png", alt_text = "rtoot logo",
+      spoiler_text = "rtoot is the best", sensitive = TRUE, token = fake_token, verbose = FALSE
+    ), NA)
   })
   vcr::use_cassette("post_toot_visibility", {
-    expect_error(x <- post_toot(status = "testing in progress, please ignore", media = "../testdata/logo.png", alt_text = "rtoot logo",
-                                spoiler_text = "rtoot is the best", visibility = "unlisted", token = fake_token, verbose = FALSE), NA)
+    expect_error(x <- post_toot(
+      status = "testing in progress, please ignore", media = "../testdata/logo.png", alt_text = "rtoot logo",
+      spoiler_text = "rtoot is the best", visibility = "unlisted", token = fake_token, verbose = FALSE
+    ), NA)
   })
   vcr::use_cassette("post_toot_language", {
-    expect_error(x <- post_toot(status = "jetzt testen", media = "../testdata/logo.png", alt_text = "rtoot logo",
-                                language = "de", visibility = "unlisted", token = fake_token, verbose = FALSE), NA)
+    expect_error(x <- post_toot(
+      status = "jetzt testen", media = "../testdata/logo.png", alt_text = "rtoot logo",
+      language = "de", visibility = "unlisted", token = fake_token, verbose = FALSE
+    ), NA)
   })
 })
 
@@ -67,3 +79,14 @@ test_that("post_user silent", {
     expect_silent(post_user("109337044410360200", action = "pin", token = fake_token2, verbose = FALSE))
   })
 })
+
+fake_token3 <- rtoot:::get_token_from_envvar("RTOOT_DEFAULT_TOKEN", check_stop = FALSE)
+fake_token3$type <- "user"
+fake_token3$instance <- "fosstodon.org"
+
+
+test_that("post_status", {
+  vcr::use_cassette("post_status_success", {
+    expect_message(post_status("110632697682444411", action = "reblog", token = fake_token3))
+  })
+})
